/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package Celbercor;

import java.io.*;
import java.net.*;
import java.security.*;
import javax.crypto.*;
import javax.crypto.spec.*;

/** (Steps 3 and 6) This class is used when a Celbercor application
 * wants to contact the ticket server or the end service.  It is
 * included as part of another message and sealed under a session key
 * known only to the end client and the server on the other end.  In
 * step 3, it is sealed under the end client/ticket server session
 * key.  In step 4, it is sealed under the end client/end service
 * session key.
 *
 * @see Celbercor.TicketRequestMessage */

public class SessionAuthenticator
  implements Serializable
{
  /** @param endClientName the name of the user wishing to call up
   * some service.  (For example, your login name.)
   *
   * @param endClientAddress the address of the workstation the end
   * client is running on.
   *
   * @param currentTime the current time in miliseconds (See
   * <tt>java.util.Date</tt> or <tt>java.lang.System</tt> for how to
   * obtain this.)  */

  public SessionAuthenticator( String endClientName,
			       InetAddress endClientAddress,
			       long currentTime )
    {
      myEndClientName = endClientName;
      myEndClientAddress = endClientAddress;
      myTime = currentTime;
    }

  public String getEndClientName()
    {
      return myEndClientName;
    }

  public InetAddress getEndClientAddress()
    {
      return myEndClientAddress;
    }

  public long getTime()
    {
      return myTime;
    }

  private String myEndClientName;
  private InetAddress myEndClientAddress;
  private long myTime;
}
