/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package Celbercor;

import java.io.*;
import java.net.*;
import java.security.*;
import javax.crypto.*;
import javax.crypto.spec.*;

/** (Step 4) This class is for messages that come back from the ticket
 * server.  It's essentially the same as the
 * <tt>AuthenticationReplyMessage</tt>, but I've made it a separate
 * class for type safety and clarity.  */

public class TicketReplyMessage
  implements Serializable
{
  /**
   * @param ticket a ticket that can be used to contact another server.
   *
   * @param sealedTicket a ticket with the same information (but a
   * different time stamp) encrypted under the other server's password
   * key.  */

 public TicketReplyMessage( Ticket ticket,
			     SealedObject sealedTicket )
    {
      myTicket = ticket;
      mySealedTicket = sealedTicket;
    }

  public Ticket getTicket()
    {
      return myTicket;
    }

  /** @return the session key from the unsealed ticket.  Once the
   * client has authenticated itself to the server, this key will be
   * used for encrypted communication between the two.  */

  public SecretKey getSessionKey()
    {
      return getTicket().getSessionKey();
    }

  public long getTime()
    {
      return getTicket().getTime();
    }

  public SealedObject getSealedTicket()
    {
      return mySealedTicket;
    }

  private Ticket myTicket;
  private SealedObject mySealedTicket;
}
