/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package Celbercor;

import java.io.*;
import java.net.*;
import java.security.*;
import javax.crypto.*;
import javax.crypto.spec.*;

/** (Step 3) This class is used when a Celbercor application wants to
 * get a ticket to contact a service.  It is sent unencrypted to the
 * ticket server, who then generates a new session ticket for the end
 * client and requested service to communicate with.  The reply is in
 * the form of a <tt>TicketReplyMessage</tt>.*/

public class TicketRequestMessage
  implements Serializable
{
  /** @param sealedTicket the sealed ticket that came to the end
   * client in step 2 as part of the authentication server's
   * <tt>AuthenticationReplyMessage</tt>.  (It is sealed under the
   * ticket server's password key.)
   *
   * @param sealedAuthenticator a <tt>SessionAuthenticator</tt> object
   * created by the end client and sealed under the end client/ticket
   * server session key.
   *
   * @param serviceName the name of the service (end server) that the
   * end client wishes to talk to. (For example, "chat room".)
   *
   * @see Celbercor.SessionAuthenticator */

  public TicketRequestMessage( SealedObject sealedTicket,
			       SealedObject sealedAuthenticator,
			       String serviceName )
    {
      mySealedTicket = sealedTicket;
      mySealedAuthenticator = sealedAuthenticator;
      myServiceName = serviceName;
    }

  public SealedObject getSealedTicket()
    {
      return mySealedTicket;
    }

  public SealedObject getSealedAuthenticator()
    {
      return mySealedAuthenticator;
    }

  public String getServiceName()
    {
      return myServiceName;
    }

  private SealedObject mySealedTicket;
  private SealedObject mySealedAuthenticator;
  private String myServiceName;
}
