/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package ChatRoom.Celbercor;

import java.io.*;
import java.net.*;
import java.util.*;
import java.security.*;
import javax.crypto.*;
import Celbercor.*;
import ChatRoom.Security.*;
import ChatRoom.Tools.*;
import ChatRoom.Tools.Reader;
import ChatRoom.Tools.Writer;
import ChatRoom.Tools.Message;

/** These are just some static methods that make creation of
 * sealed-object readers and writers easier.  We have to create a
 * <tt>Cipher</tt> to create a sealed-object reader or writer.
 * Creating a cipher can throw an exception, and even though that
 * isn't supposed to happen if we use the encryption library properly,
 * we still have to satisfy the compiler.  These functions hide all
 * that dirty work. */

public abstract class RWFactory
{

  public static SealedObjectReader 
  createReader( SecretKey key, ObjectInput in )
    {
      Cipher c = null;
      SealedObjectReader rval = null;
      try
	{
	  c = EncryptionStandard.getInstance().createCipher();
	  c.init( Cipher.DECRYPT_MODE, key );
	  rval = new SealedObjectReader( c, in );
	}
      catch( Exception ex )
	{
	  System.out.println( "Unexpected exception while reading:" );
	  ex.printStackTrace();
	  rval = null;
	}
      return rval;
    }

  public static SealedObjectWriter 
  createWriter( SecretKey key, ObjectOutput out )
    {
      Cipher c = null;
      SealedObjectWriter rval = null;
      try
	{
	  c = EncryptionStandard.getInstance().createCipher();
	  c.init( Cipher.ENCRYPT_MODE, key );
	  rval = new SealedObjectWriter( c, out );
	}
      catch( Exception ex )
	{
	  System.out.println( "Unexpected exception:\n" );
	  ex.printStackTrace();
	  rval = null;
	}
      return rval;
    }


}
