/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package ChatRoom;
import ChatRoom.GUI.*;
import ChatRoom.Client.*;
import ChatRoom.Tools.*;
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.net.*;

/** This <tt>main()</tt> function starts a GUI chat room client which
 * uses multicasting.  (Hence the "M".)  It doesn't need a server as
 * the router system does all the work. */

public class MClient
{
  /**
   * Start a mutlicast client.  It expects the following arguments:
   *
   * <pre>
   * java ChatRoom.MClient <i>name</i> [<i>addr</i> [<i>port</i> [<i>ttl</i>]]]
   * </pre>
   *
   * where <i>name</i> is the name you wish to chat under, <i>addr</i>
   * is the multicast address to use (default value is {@link
   * ChatRoomConstants#DEFAULT_MULTICAST_ADDRESS
   * <tt>ChatRoomConstants.DEFAULT_MULTICAST_ADDRESS</tt>}),
   * <i>port</i> is the port to listen to (default value is {@link
   * ChatRoomConstants#DEFAULT_PORT
   * <tt>ChatRoomConstants.DEFAULT_PORT</tt>}), and <i>ttl</i> is the
   * time-to-live field for messages (default value is 32).  (The
   * time-to-live is part of IP.  32 is supposed to mean a multicast
   * packet should go all over the site.  Other values restrict
   * packets to a subnet, a continent, etc., but many places set their
   * routers not to allow multicast packets out of the local
   * system.)*/

  public static void main( String args[] )
    {
      String name = null;
      String host = ChatRoomConstants.DEFAULT_MULTICAST_ADDRESS;
      int port = ChatRoomConstants.DEFAULT_PORT;
      int ttl = 32;

      Client c;
      SimpleUI g;
      Frame frame;

      if( args.length < 1 )
	{
	  System.out
	    .println( "Arguments: name [address [port [time-to-live]]]" );
	  System.exit(1);
	}

      name = args[0];

      if( args.length >= 2 )
	{
	  host = args[1];
	}
      if( args.length >= 3 )
	{
	  port = new Integer( args[2] ).intValue();
	}
      if( args.length >= 4 )
	{
	  ttl = new Integer( args[3] ).intValue();
	}

      System.out.println( "Listening for chat: " + host 
			  + ':' + port
			  + "; ttl:" + ttl );

      try
	{
	  c = Client.createViaMulticast( 
	      ChatRoomConstants.DEFAULT_MAX_PACKET_SIZE,
              InetAddress.getByName( host ), 
	      port,
	      ttl );
	}
      catch( IOException ex )
	{
	  System.out.println( "Error establishing connection:\n" + ex );
	  return;
	}

      g = new SimpleUI( name, c, host, port );
      frame = new Frame( "Chat:" + name );
      frame.add( g, "Center" );
      frame.pack();
      frame.addWindowListener( new ExitWhenClosed() );
      frame.setVisible( true );

      c.run();
      System.out.println( "Lost contact somehow..." );
      System.exit(0);
    }


}
