/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package ChatRoom;

import ChatRoom.Client.*;
import ChatRoom.Tools.*;
import java.io.*;
import java.net.*;

/** This class just listens for messages from a server and prints them
 * to the console.  It never sends any messages of its own.  */

public class MonitorClient
{

  /**
   * Start a monitor client.  It takes arguments:
   * 
   * <pre>
   * java ChatRoom.MonitorClient [<i>host</i> [<i>port</i>]]
   * </pre>
   *
   * where <i>host</i> is the host name of the chat server (default
   * value is {@link ChatRoomConstants#DEFAULT_HOST
   * <tt>ChatRoomConstants.DEFAULT_HOST</tt>}, and <i>port</i> is the
   * port the chat server is listening to (default value is {@link
   * ChatRoomConstants#DEFAULT_PORT
   * <tt>ChatRoomConstants.DEFAULT_PORT</tt>}).  */

  public static void main( String args[] )
    {
      String host = ChatRoomConstants.DEFAULT_HOST;
      int port = ChatRoomConstants.DEFAULT_PORT;
      Socket s;
      Client c;

      if( args.length >= 1 )
	{
	  host = args[0];
	}
      if( args.length >= 2 )
	{
	  port = new Integer( args[1] ).intValue();
	}
      System.out.println( "Listening for chat: " + host + ":" + port );

      try
	{
	  c = Client.createViaInternet( host, port );
	}
      catch( UnknownHostException ex )
	{
	  System.out.println( "Host " + host + " could not be contacted." );
	  return;
	}
      catch( IOException ex )
	{
	  System.out.println( "Could not contact chat room server." );
	  return;
	}
      c.setHandler( new MessagePrinter( System.out ) );
      c.run();
      System.out.println( "Lost contact with the server." );
    }
}
