/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package ChatRoom;

import ChatRoom.GUI.*;
import ChatRoom.Client.*;
import ChatRoom.Tools.*;
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.net.*;

/** This <tt>main()</tt> function starts a chat room client which
 * talks to a server. (Hence the "S".) */

public class SClient
{
  /**
   * Start a client.  It takes arguments:
   *
   * <pre>
   * java ChatRoom.SClient <i>name</i> [<i>host</i> [<i>port</i>]]
   * </pre>
   *
   * where <i>name</i> is the name you want to chat under, <i>host</i>
   * is the host where the chat server is running (default value is
   * {@link ChatRoomConstants#DEFAULT_HOST
   * <tt>ChatRoomConstants.DEFAULT_HOST</tt>}), and <i>port</i> is the
   * port the chat server is listening to (default value is {@link
   * ChatRoomConstants#DEFAULT_PORT
   * <tt>ChatRoomConstants.DEFAULT_PORT</tt>}).
   * */

  public static void main( String args[] )
    {
      String name = null;
      String host = ChatRoomConstants.DEFAULT_HOST;
      int port = ChatRoomConstants.DEFAULT_PORT;
      Client c = null;
      SimpleUI g;
      Frame frame;

      if( args.length < 1 )
	{
	  System.out.println( "Arguments: name [host [port]]" );
	  System.exit(1);
	}

      name = args[0];

      if( args.length >= 2 )
	{
	  host = args[1];
	}
      if( args.length >= 3 )
	{
	  port = Integer.parseInt( args[2] );
	}

      System.out.println( "Listening for chat: " + host + ":" + port );

      try
	{
	  c = Client.createViaInternet( host, port );
	}
      catch( UnknownHostException ex )
	{
	  System.out.println( "Unable to contact host " + host );
	  System.exit(1);
	}
      catch( IOException ex )
	{
	  System.out.println( "Could not contact chat room server." );
	  System.exit(2);
	}

      g = new SimpleUI( name, c, host, port );
      frame = new Frame( "Chat:" + name );
      frame.add( g, "Center" );
      frame.pack();
      frame.addWindowListener( new ExitWhenClosed() );
      frame.setVisible( true );

      c.run();
      System.out.println( "Lost contact with the server." );
      System.exit(0);
    }


}
