/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package ChatRoom.Security;

import java.io.*;
import java.security.*;
import javax.crypto.*;
import ChatRoom.Tools.Reader;
import ChatRoom.Tools.Writer;
import ChatRoom.Tools.Message;

/** This reader class can decipher messages signed with a nonce. */

public class SignedSealedObjectReader
  implements Reader
{
  public SignedSealedObjectReader( Cipher c, ObjectInput in, Object nonce )
    {
      myCipher = c;
      myInput = in;
      myNonce = nonce;
    }

  public Message getNextMessage()
    {
      SealedObject so = null;
      SignedMessage sm = null;
      Message m = null;
      
      try
	{
	  so = (SealedObject)myInput.readObject();
	  sm = (SignedMessage)so.getObject( myCipher );
	  if( sm.getNonce().equals( myNonce ) )
	    {
	      m = sm.getMessage();
	    }
	  else
	    {
	      System.out.println( "Nonce is wrong:\n"
				  + sm.getNonce()
				  + "\nshould be:\n"
				  + myNonce );
	      m = null;
	    }
	}
      catch( EOFException ex )
	{
	  m = null;
	}
      catch( Exception ex )
	{
	  System.out.println( "Unexpected exception while reading:" );
	  ex.printStackTrace();
	  m = null;
	}
      return m;
    }

  private Cipher myCipher;
  private ObjectInput myInput;
  private Object myNonce;
}
