/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package ChatRoom.Tools;

import java.net.*;

/** These are constants used as default values by various clients and
 *  servers.  */

public abstract class ChatRoomConstants
{
  /** The default IP port. Set to 10000. */

  public static final int DEFAULT_PORT = 10000;

  /** The default host for servers. Set to the local host's real name,
   * or to just "localhost" if that isn't possible.*/

  public static final String DEFAULT_HOST;

  static
    {
      InetAddress a = null;
      try
	{
	  a = InetAddress.getLocalHost();
	}
      catch( UnknownHostException ex )
	{
	  ex.printStackTrace();
	}
      
      if( a == null )
	{
	  DEFAULT_HOST = "localhost";
	}
      else
	{
	  DEFAULT_HOST = a.getHostName();
	}
    }

  /** The default multicast address.  Set to "224.1.2.3" because I
   * couldn't come up with anything better.  Multicast addresses are
   * in a particular range of IP address space, and you just pick one
   * and hope no one else is using it. */

  public static final String DEFAULT_MULTICAST_ADDRESS = "224.1.2.3";

  /** The default maximum packet size for use with multicast sockets.
   * Set to 32k. */

  public static final int DEFAULT_MAX_PACKET_SIZE = 1<<15;

}
