/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package ChatRoom.Tools;

import java.io.*;

/** This class represents a means of reading a message from a DataInput
 * object, normally a DataInputStream.  The format is:
 *
 * <ol>
 * <li> byte nameLen: Length of name in bytes.
 * <li> byte[nameLen] name: Name of sender
 * <li> int msgLen: Length of message in bytes.
 * <li> byte[msgLen] msg: Message text
 * </ol>
 * 
 * It assumes network byte order (big-endian, high byte first).
 * @see ChatRoom.Tools.DataOutputWriter
 **/
 
public class DataInputReader 
  implements Reader
{
  public DataInputReader( DataInput input )
    {
      myInput = input;
    }

  /** This does the actual work of reading a message.  It is public
   * and static to make it easy to use in other classes.
   * @return A new message, or null if input fails. */

  public static Message readMessage( DataInput in )
    {
      Message m = new Message();
      int size;
      byte text[];
      
      try
	{
	  size = in.readByte();
	  text = new byte[size];
	  in.readFully( text );
	  m.setName( new String( text ) );
	  size = in.readInt();
	  text = new byte[size];
	  in.readFully( text );
	  m.setText( new String( text ) );
	}
      catch( IOException ex )
	{
	  m = null;
	}
      return m;
    }

  /** Wait for and return the next message.  Return null if the
   * connection has failed. */

  public Message getNextMessage()
    {
      return readMessage( myInput );
    }

  private DataInput myInput;
}
