/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package ChatRoom.Tools;

import java.net.*;
import java.io.*;

/** This class represents a source of messages which come down a
 * DatagramSocket.  It's useful for UDP and multicast chat rooms. */

public class DatagramReader
  implements Reader
{

  /** @param s a socket to read from
   *
   * @param a address to send to
   *
   * @param port port to send to
   *
   * @param packetSize how big the biggest packets will be.
   */

  public DatagramReader( DatagramSocket s, InetAddress a, 
			 int port, int packetSize )
    {
      mySocket = s;
      mySize = packetSize;
    }

  /** Wait for and return the next message.  Return null if the
   * connection has failed. */

  public Message getNextMessage()
    {
      DataInput in;
      byte buffer[] = new byte[mySize];
      DatagramPacket p = new DatagramPacket( buffer, buffer.length );

      try
	{
	  mySocket.receive( p );
	}
      catch( IOException ex )
	{
	  return null;
	}

      in = new DataInputStream( 
         new ByteArrayInputStream( p.getData() ) );

      return DataInputReader.readMessage( in );
    }

  private DatagramSocket mySocket;
  private int mySize;
}
