package FlamingSword;

import java.io.*;
import java.net.*;
import java.util.*;
import java.security.*;
import javax.crypto.*;

/** This is a base class for things ("agents", both clients and
 * servers) that use public and private keys and must communicate with
 * a Flaming Sword authentication server.  */

public abstract class AgentBase
{
  /** @param fileName abbreviated name of files where the server's
   * public and private keys are held. (<tt>.pub</tt> and
   * <tt>.pri</tt> will be appended to this name to find the actual
   * files.)
   *
   * @param authFileName abbreviated name of the file where the
   * authentication server's public key is held. */

  public void initialize( String fileName, String authFileName )
    throws IOException, ClassNotFoundException, GeneralSecurityException
    {
      InputStream fileIn;
      ObjectInput in;

      System.out.println( "Reading my public key from " 
			  + fileName + ".pub" );

      fileIn = new FileInputStream( fileName + ".pub" );
      in = new ObjectInputStream( fileIn );
      myPublicKey = (PublicKey)in.readObject();

      System.out.println( "Reading my private key from "
			  + fileName + ".pri" );

      fileIn = new FileInputStream( fileName + ".pri" );
      in = new ObjectInputStream( fileIn );
      myPrivateKey = (PrivateKey)in.readObject();
      
      myPrivateCipher = 
	EncryptionStandard.getInstance().createCipher();
      myPrivateCipher.init( Cipher.ENCRYPT_MODE, myPrivateKey );

      System.out.println( "Reading authentication server public key from "
			  + authFileName + ".pub" );

      fileIn = new FileInputStream( authFileName + ".pub" );
      in = new ObjectInputStream( fileIn );
      myAuthPublicKey = (PublicKey)in.readObject();
    }

  public PrivateKey getPrivateKey()
    {
      return myPrivateKey;
    }

  public Cipher getPrivateCipher()
    {
      return myPrivateCipher;
    }

  public PublicKey getPublicKey()
    {
      return myPublicKey;
    }

  public PublicKey getAuthPublicKey()
    {
      return myAuthPublicKey;
    }

  private PrivateKey myPrivateKey;
  private Cipher myPrivateCipher;
  private PublicKey myPublicKey;
  private PublicKey myAuthPublicKey;

}
