package FlamingSword;

import java.net.InetAddress;
import java.util.*;
import java.security.*;
import java.io.*;
import javax.crypto.*;

/** (Step 2) This class represents the message sent in the second
 * stage of the protocol, when the public key server sends back the
 * session ticket doubly encoded.  This reply will be encrypted in the
 * client's public key.  */

public class AuthenticationReplyMessage
  implements java.io.Serializable
{
  /** @param clientInfoTicket a ticket with the name and public key of
   * the end client, sealed under the authentication server's private
   * key.
   *
   * @param serviceInfoTicket a ticket with the name and public key of
   * the end service, sealed under the authentication server's private
   * key.  */

  public AuthenticationReplyMessage( SealedObject clientInfoTicket,
				     SealedObject serviceInfoTicket )
    {
      mySealedClientTicket = clientInfoTicket;
      mySealedServiceTicket = serviceInfoTicket;
    }

  public SealedObject getSealedClientTicket()
    {
      return mySealedClientTicket;
    }

  public SealedObject getSealedServiceTicket()
    {
      return mySealedServiceTicket;
    }

  public void decrypt( PublicKey authServerKey )
    throws IOException, GeneralSecurityException, ClassNotFoundException
    {
      myServiceTicket = 
	(Ticket)mySealedServiceTicket.getObject( authServerKey );
      myClientTicket =
	(Ticket)mySealedClientTicket.getObject( authServerKey );
    }

  public Ticket getServiceTicket()
    {
      return myServiceTicket;
    }

  public Ticket getClientTicket()
    {
      return myClientTicket;
    }

  private SealedObject mySealedServiceTicket;
  private transient Ticket myServiceTicket;
  private SealedObject mySealedClientTicket;
  private transient Ticket myClientTicket;
}
