package FlamingSword;

import java.io.*;
import java.math.BigInteger;
import java.util.*;
import java.security.*;
import java.security.spec.*;
import java.security.interfaces.*;
import javax.crypto.*;
import javax.crypto.spec.*;
import javax.crypto.interfaces.*;

/** This class is a singleton which hides some of the gory details of
 * the encryption library.  There is at most one instance of this
 * class per program, which may be accessed via the
 * static <tt>getInstance()</tt> method:
 * <pre>
 * EncryptionStandard.getInstance().initializeEncryptionLibrary();
 * Cipher c = EncryptionStandard.getInstance().createCipher();
 * </pre> */

public class EncryptionStandard
{
  /**
   * (This constructor is protected to enforce the one-instance rule.)
   */

  protected EncryptionStandard()
    {
    }

  /** @return the single instance of <tt>EncryptionStandard</tt>,
   * creating it if necessary  */

  public static EncryptionStandard getInstance()
    {
      if( ourInstance == null )
	{
	  ourInstance = new EncryptionStandard();
	}

      return ourInstance;
    }

  private static EncryptionStandard ourInstance = null;

  /** Initialize the encryption library, installing whatever providers
   * are needed.  You must call this function before using any
   * encryption functions! */

  public void initializeEncryptionLibrary()
    throws GeneralSecurityException
    {
	// Provider p = new com.sun.crypto.provider.SunJCE();
	// Security.addProvider( p );
    }

  /**
   * Generate a pair of keys (one public, one private).
   */

  public KeyPair generateKeyPair()
    throws GeneralSecurityException
    {
      if( myGenerator == null )
	{
	  myGenerator = KeyPairGenerator.getInstance( "RSA" );
	  myGenerator.initialize( 512 );
	}

      return myGenerator.generateKeyPair();
    }

  /** Create a cipher, which can be used with either a public key or a
   * private key.  */

  public Cipher createCipher()
    throws GeneralSecurityException
    {
      return Cipher.getInstance( "RSA" );
    }

  private KeyPairGenerator myGenerator;

  /** This <tt>main()</tt> function is for debugging purposes only.
   * It initializes the encryption library to be sure all the
   * providers are available.  */

  public static void main( String args[] )
    {
      try
	{
	  EncryptionStandard.getInstance().initializeEncryptionLibrary();
	}
      catch( Exception ex )
	{
	  ex.printStackTrace();
	}
    }
}
