package FlamingSword;

import java.net.InetAddress;
import java.util.*;
import javax.crypto.*;
import java.security.*;

/** This is a data class, used by several of the message classes to
 * hold information needed by the various agents in the protocol.  */

public class Ticket 
  implements java.io.Serializable
{
  /**
   * @param agent the name of a client, user or server
   *
   * @param pkey the public key that goes with that client, user, or server
   *
   * @param nonce an object created by the authentication server which
   * is used as a shared secret between a client and server
   *
   * @param time a time stamp
   */

  public Ticket( String agent, PublicKey pkey, Object nonce, long time )
    {
      myAgent = agent;
      myKey = pkey;
      myNonce = nonce;
      myTime = time;
    }

  public String getAgent()
    {
      return myAgent;
    }

  public PublicKey getPublicKey()
    {
      return myKey;
    }

  public long getTime()
    {
      return myTime;
    }

  public Object getNonce()
    {
      return myNonce;
    }

  /** How long in milliseconds a ticket remains valid.  Tickets must
   * be used before this much time expires, but once they are used,
   * the connection they enabled remains valid indefinitely.  (Current
   * value is 5 minutes).*/

  public static final long TIME_GAP = 5*60*1000; // this is 5 min.

  /** Compare two times to see if they are separated by more than
   * <tt>TIME_GAP</tt>ms.
   * 
   * @return <tt>null</tt> if the times are close enough, an error
   * message if they are too far apart.  */

  public static String checkTimes( long t1, long t2 )
    {
      String msg = null;

      if( Math.abs(t1-t2) > TIME_GAP )
	{
	  msg = "Bad times: "
	    + (new Date(t1))
	    + " more than " + TIME_GAP 
	    + " ms away from "
	    + (new Date(t2));
	}
      return msg;
    }

  /**
   * Check the data in this ticket against the given information.
   *
   * @return <tt>null</tt> if everything checks out, an error message
   * if not.  */

  public String checkConsistency( String agent, long time )
    {
      String msg = null;
      if( !myAgent.equals(agent) )
	{
	  msg = "Wrong agent: " + myAgent + " should be " + agent;
	}
      else
	{
	  msg = checkTimes( myTime, time );
	}
      return msg;
    }

  private String myAgent;
  private PublicKey myKey;
  private Object myNonce;
  private long myTime;
}
